@@ -94,31 +94,31 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_iam
-import aws_cdk.aws_ssm
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_ssm as _aws_cdk_aws_ssm_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
-@jsii.implements(aws_cdk.aws_ssm.IStringParameter, aws_cdk.aws_ssm.IParameter)
+@jsii.implements(_aws_cdk_aws_ssm_ceddda9d.IStringParameter, _aws_cdk_aws_ssm_ceddda9d.IParameter)
 class StringParameter(
-    aws_cdk.Resource,
+    _aws_cdk_ceddda9d.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@pepperize/cdk-ssm-parameters-cross-region.StringParameter",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         parameter_name: builtins.str,
         region: builtins.str,
         string_value: builtins.str,
         allowed_pattern: typing.Optional[builtins.str] = None,
-        data_type: typing.Optional[aws_cdk.aws_ssm.ParameterDataType] = None,
+        data_type: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterDataType] = None,
         description: typing.Optional[builtins.str] = None,
-        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        tier: typing.Optional[aws_cdk.aws_ssm.ParameterTier] = None,
+        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+        tier: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterTier] = None,
     ) -> None:
         '''
         :param scope: -
@@ -133,21 +133,7 @@ class StringParameter(
         :param tier: The tier of the string parameter. Default: - undefined
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                parameter_name: builtins.str,
-                region: builtins.str,
-                string_value: builtins.str,
-                allowed_pattern: typing.Optional[builtins.str] = None,
-                data_type: typing.Optional[aws_cdk.aws_ssm.ParameterDataType] = None,
-                description: typing.Optional[builtins.str] = None,
-                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-                tier: typing.Optional[aws_cdk.aws_ssm.ParameterTier] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a1dbce2fa2ceed9bca867403a768a46c247336ba8136347015d7e640bd2714a7)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = StringParameterProps(
@@ -167,15 +153,15 @@ class StringParameter(
     @builtins.classmethod
     def from_string_parameter_attributes(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         region: builtins.str,
-        type: typing.Optional[aws_cdk.aws_ssm.ParameterType] = None,
+        type: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterType] = None,
         version: typing.Optional[jsii.Number] = None,
         parameter_name: builtins.str,
         simple_name: typing.Optional[builtins.bool] = None,
-    ) -> aws_cdk.aws_ssm.IStringParameter:
+    ) -> _aws_cdk_aws_ssm_ceddda9d.IStringParameter:
         '''Imports an external string parameter with name and optional version.
 
         :param scope: -
@@ -187,18 +173,7 @@ class StringParameter(
         :param simple_name: Indicates of the parameter name is a simple name (i.e. does not include "/" separators). This is only required only if ``parameterName`` is a token, which means we are unable to detect if the name is simple or "path-like" for the purpose of rendering SSM parameter ARNs. If ``parameterName`` is not specified, ``simpleName`` must be ``true`` (or undefined) since the name generated by AWS CloudFormation is always a simple name. Default: - auto-detect based on ``parameterName``
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                region: builtins.str,
-                type: typing.Optional[aws_cdk.aws_ssm.ParameterType] = None,
-                version: typing.Optional[jsii.Number] = None,
-                parameter_name: builtins.str,
-                simple_name: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__01e536e68070f5950f8d602ebb785fe1287210e51a21ecd0d04e72f10c57e066)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         attrs = StringParameterAttributes(
@@ -209,17 +184,17 @@ class StringParameter(
             simple_name=simple_name,
         )
 
-        return typing.cast(aws_cdk.aws_ssm.IStringParameter, jsii.sinvoke(cls, "fromStringParameterAttributes", [scope, id, attrs]))
+        return typing.cast(_aws_cdk_aws_ssm_ceddda9d.IStringParameter, jsii.sinvoke(cls, "fromStringParameterAttributes", [scope, id, attrs]))
 
     @jsii.member(jsii_name="fromStringParameterName")
     @builtins.classmethod
     def from_string_parameter_name(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         region: builtins.str,
         parameter_name: builtins.str,
-    ) -> aws_cdk.aws_ssm.IStringParameter:
+    ) -> _aws_cdk_aws_ssm_ceddda9d.IStringParameter:
         '''Imports an external string parameter by name and region.
 
         :param scope: -
@@ -228,25 +203,18 @@ class StringParameter(
         :param parameter_name: -
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                region: builtins.str,
-                parameter_name: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d442daa1706014f1b04f6498688c3408c9e86923fb2fcfa175a8170f5a5fba63)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
-        return typing.cast(aws_cdk.aws_ssm.IStringParameter, jsii.sinvoke(cls, "fromStringParameterName", [scope, id, region, parameter_name]))
+        return typing.cast(_aws_cdk_aws_ssm_ceddda9d.IStringParameter, jsii.sinvoke(cls, "fromStringParameterName", [scope, id, region, parameter_name]))
 
     @jsii.member(jsii_name="valueFromLookup")
     @builtins.classmethod
     def value_from_lookup(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         region: builtins.str,
         parameter_name: builtins.str,
     ) -> builtins.str:
@@ -260,43 +228,39 @@ class StringParameter(
         :param parameter_name: -
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                region: builtins.str,
-                parameter_name: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__10597bc8a55d8c6578585c999111a0c480e02daa0cf199fb03676b34601b3bbb)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "valueFromLookup", [scope, region, parameter_name]))
 
     @jsii.member(jsii_name="grantRead")
-    def grant_read(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+    def grant_read(
+        self,
+        grantee: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+    ) -> _aws_cdk_aws_iam_ceddda9d.Grant:
         '''Grants read (DescribeParameter, GetParameter, GetParameterHistory) permissions on the SSM Parameter.
 
         :param grantee: -
         '''
         if __debug__:
-            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2f1ca986f4d1b557fd527669e0a952b36b02c5775a61aafb72c33a348b2a8230)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
-        return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
     @jsii.member(jsii_name="grantWrite")
-    def grant_write(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+    def grant_write(
+        self,
+        grantee: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+    ) -> _aws_cdk_aws_iam_ceddda9d.Grant:
         '''Grants write (PutParameter) permissions on the SSM Parameter.
 
         :param grantee: -
         '''
         if __debug__:
-            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4cdbc0640aadf0680ae287ae5c113c1f62ec38dc84c782b6d64848f8e10c6bbf)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
-        return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantWrite", [grantee]))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Grant, jsii.invoke(self, "grantWrite", [grantee]))
 
     @builtins.property
     @jsii.member(jsii_name="parameterArn")
@@ -327,13 +291,13 @@ class StringParameter(
 
     @builtins.property
     @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.TagManager:
-        return typing.cast(aws_cdk.TagManager, jsii.get(self, "tags"))
+    def tags(self) -> _aws_cdk_ceddda9d.TagManager:
+        return typing.cast(_aws_cdk_ceddda9d.TagManager, jsii.get(self, "tags"))
 
 
 @jsii.data_type(
     jsii_type="@pepperize/cdk-ssm-parameters-cross-region.StringParameterAttributes",
-    jsii_struct_bases=[aws_cdk.aws_ssm.StringParameterAttributes],
+    jsii_struct_bases=[_aws_cdk_aws_ssm_ceddda9d.StringParameterAttributes],
     name_mapping={
         "parameter_name": "parameterName",
         "simple_name": "simpleName",
@@ -342,13 +306,13 @@ class StringParameter(
         "region": "region",
     },
 )
-class StringParameterAttributes(aws_cdk.aws_ssm.StringParameterAttributes):
+class StringParameterAttributes(_aws_cdk_aws_ssm_ceddda9d.StringParameterAttributes):
     def __init__(
         self,
         *,
         parameter_name: builtins.str,
         simple_name: typing.Optional[builtins.bool] = None,
-        type: typing.Optional[aws_cdk.aws_ssm.ParameterType] = None,
+        type: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterType] = None,
         version: typing.Optional[jsii.Number] = None,
         region: builtins.str,
     ) -> None:
@@ -360,22 +324,13 @@ class StringParameterAttributes(aws_cdk.aws_ssm.StringParameterAttributes):
         :param region: The region to retrieve the parameter from. See AWS.SSM.region for more information.
         '''
         if __debug__:
-            def stub(
-                *,
-                parameter_name: builtins.str,
-                simple_name: typing.Optional[builtins.bool] = None,
-                type: typing.Optional[aws_cdk.aws_ssm.ParameterType] = None,
-                version: typing.Optional[jsii.Number] = None,
-                region: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3579c46e8be7aaa49bdc9227a9b4b7d96dd8e48c5e2503fc99ff127bd9017282)
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
             check_type(argname="argument simple_name", value=simple_name, expected_type=type_hints["simple_name"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "parameter_name": parameter_name,
             "region": region,
         }
@@ -415,13 +370,13 @@ class StringParameterAttributes(aws_cdk.aws_ssm.StringParameterAttributes):
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def type(self) -> typing.Optional[aws_cdk.aws_ssm.ParameterType]:
+    def type(self) -> typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterType]:
         '''The type of the string parameter.
 
         :default: ParameterType.STRING
         '''
         result = self._values.get("type")
-        return typing.cast(typing.Optional[aws_cdk.aws_ssm.ParameterType], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterType], result)
 
     @builtins.property
     def version(self) -> typing.Optional[jsii.Number]:
@@ -476,10 +431,10 @@ class StringParameterProps:
         region: builtins.str,
         string_value: builtins.str,
         allowed_pattern: typing.Optional[builtins.str] = None,
-        data_type: typing.Optional[aws_cdk.aws_ssm.ParameterDataType] = None,
+        data_type: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterDataType] = None,
         description: typing.Optional[builtins.str] = None,
-        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        tier: typing.Optional[aws_cdk.aws_ssm.ParameterTier] = None,
+        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+        tier: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterTier] = None,
     ) -> None:
         '''Properties needed to create a String SSM parameter.
 
@@ -493,19 +448,7 @@ class StringParameterProps:
         :param tier: The tier of the string parameter. Default: - undefined
         '''
         if __debug__:
-            def stub(
-                *,
-                parameter_name: builtins.str,
-                region: builtins.str,
-                string_value: builtins.str,
-                allowed_pattern: typing.Optional[builtins.str] = None,
-                data_type: typing.Optional[aws_cdk.aws_ssm.ParameterDataType] = None,
-                description: typing.Optional[builtins.str] = None,
-                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-                tier: typing.Optional[aws_cdk.aws_ssm.ParameterTier] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__45f8a685875be7172ad63f8dded88f74a9b92986fb8728ed45b207d027f47aa8)
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument string_value", value=string_value, expected_type=type_hints["string_value"])
@@ -514,7 +457,7 @@ class StringParameterProps:
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument removal_policy", value=removal_policy, expected_type=type_hints["removal_policy"])
             check_type(argname="argument tier", value=tier, expected_type=type_hints["tier"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "parameter_name": parameter_name,
             "region": region,
             "string_value": string_value,
@@ -572,13 +515,13 @@ class StringParameterProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def data_type(self) -> typing.Optional[aws_cdk.aws_ssm.ParameterDataType]:
+    def data_type(self) -> typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterDataType]:
         '''The data type of the parameter, such as ``text`` or ``aws:ec2:image``.
 
         :default: - undefined
         '''
         result = self._values.get("data_type")
-        return typing.cast(typing.Optional[aws_cdk.aws_ssm.ParameterDataType], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterDataType], result)
 
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
@@ -590,22 +533,22 @@ class StringParameterProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy]:
         '''Whether to retain or delete the parameter on CloudFormation delete event.
 
         :default: - DESTROY
         '''
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
+        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy], result)
 
     @builtins.property
-    def tier(self) -> typing.Optional[aws_cdk.aws_ssm.ParameterTier]:
+    def tier(self) -> typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterTier]:
         '''The tier of the string parameter.
 
         :default: - undefined
         '''
         result = self._values.get("tier")
-        return typing.cast(typing.Optional[aws_cdk.aws_ssm.ParameterTier], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterTier], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -626,3 +569,86 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__a1dbce2fa2ceed9bca867403a768a46c247336ba8136347015d7e640bd2714a7(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    parameter_name: builtins.str,
+    region: builtins.str,
+    string_value: builtins.str,
+    allowed_pattern: typing.Optional[builtins.str] = None,
+    data_type: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterDataType] = None,
+    description: typing.Optional[builtins.str] = None,
+    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+    tier: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterTier] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__01e536e68070f5950f8d602ebb785fe1287210e51a21ecd0d04e72f10c57e066(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    region: builtins.str,
+    type: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterType] = None,
+    version: typing.Optional[jsii.Number] = None,
+    parameter_name: builtins.str,
+    simple_name: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d442daa1706014f1b04f6498688c3408c9e86923fb2fcfa175a8170f5a5fba63(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    region: builtins.str,
+    parameter_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__10597bc8a55d8c6578585c999111a0c480e02daa0cf199fb03676b34601b3bbb(
+    scope: _constructs_77d1e7e8.Construct,
+    region: builtins.str,
+    parameter_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2f1ca986f4d1b557fd527669e0a952b36b02c5775a61aafb72c33a348b2a8230(
+    grantee: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4cdbc0640aadf0680ae287ae5c113c1f62ec38dc84c782b6d64848f8e10c6bbf(
+    grantee: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3579c46e8be7aaa49bdc9227a9b4b7d96dd8e48c5e2503fc99ff127bd9017282(
+    *,
+    parameter_name: builtins.str,
+    simple_name: typing.Optional[builtins.bool] = None,
+    type: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterType] = None,
+    version: typing.Optional[jsii.Number] = None,
+    region: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__45f8a685875be7172ad63f8dded88f74a9b92986fb8728ed45b207d027f47aa8(
+    *,
+    parameter_name: builtins.str,
+    region: builtins.str,
+    string_value: builtins.str,
+    allowed_pattern: typing.Optional[builtins.str] = None,
+    data_type: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterDataType] = None,
+    description: typing.Optional[builtins.str] = None,
+    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+    tier: typing.Optional[_aws_cdk_aws_ssm_ceddda9d.ParameterTier] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
